pub enum BlockItem {
Positional(ParserAst),
Named {
name: String,
parser: ParserAst,
},
}Expand description
One item in a block(...) (7.5).
Variants
Positional(ParserAst)
A positional parser. If it is a named-capture template, its captures flatten into the enclosing block record; otherwise (a scalar) it must be the sole contributor or validation rejects it for an unclear field name (7.5).
Named
A named item name: parser contributing one field.